@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 sub new {
     return bless {}, shift;
@@ -17,10 +17,14 @@ sub mock {
     my $sub = shift;
     %{ $self } = @_;
 
+    # can't do side_effect and return_value in one pass (yet)
+
     if (defined $self->{return_value} && defined $self->{side_effect}){
         die "use only one of return_value or side_effect";
     }
 
+    # side_effect must be a legit code reference
+
     if (defined $self->{side_effect} && ref $self->{side_effect} ne 'CODE'){
         die "side_effect param must be a cref";
     }
@@ -38,7 +42,6 @@ sub mock {
             $self->{side_effect}->() if $self->{side_effect};
         };
     }
-
     return $self;
 }
 sub called {
@@ -48,8 +51,7 @@ sub call_count {
     return shift->{call_count};
 }
 sub name {
-    my $self = shift;
-    return $self->{name};  
+    return shift->{name};  
 }
 sub reset {
     my $self = shift;
@@ -57,7 +59,7 @@ sub reset {
         delete $self->{$_};
     }
 }
-sub _end {}; # vim placeholder
+sub _end {}; # vim fold placeholder
 
 1;
 =head1 NAME
@@ -95,11 +97,14 @@ Mock::Sub - Mock package, module, object and standard subroutines, with ability
 
     # have the mocked sub return something when it's called
 
-    $foo = $mock->mock('Package::foo', return_value => 'True');
+    my $foo = $mock->mock('Package::foo', return_value => 'True');
+    my $return = Package::foo;
 
     # have the mocked sub perform an action
 
     $foo = $mock->mock('Package::foo', side_effect => sub { die "eval catch"; });
+    Package::foo;
+    print 'died' if $@;
 
     # reset the mocked sub for re-use within the same scope
 
